@@ -1,4 +1,4 @@
-// Copyright (c) 2021 GreenYun Organization
+// Copyright (c) 2022 GreenYun Organization
 //
 // This software is released under the MIT License.
 // https://opensource.org/licenses/MIT
@@ -8,9 +8,9 @@ macro_rules! enum_lang_matches {
         $($val:path => $en:expr, $tc:expr, $sc:expr),+ $(,)?) => {
         match $case {
             $($val => match $lang {
-                crate::common::Lang::en => $en,
-                crate::common::Lang::tc => $tc,
-                crate::common::Lang::sc => $sc,
+                crate::common::Lang::EN => $en,
+                crate::common::Lang::TC => $tc,
+                crate::common::Lang::SC => $sc,
             }),
             +
         }
