@@ -1,4 +1,4 @@
-// Copyright (c) 2021 GreenYun Organization
+// Copyright (c) 2022 GreenYun Organization
 //
 // This software is released under the MIT License.
 // https://opensource.org/licenses/MIT
@@ -9,10 +9,10 @@ use chrono::{DateTime, FixedOffset};
 use serde::Deserialize;
 
 use super::{WarningStatementCode, WarningSubtypeCode};
-use crate::common::Message;
+use crate::{common::Message, fetch::impl_api};
 
 /// The details of weather warning information.
-#[derive(Debug, Deserialize)]
+#[derive(Clone, Debug, Deserialize)]
 pub struct InfoDetail {
     pub contents: Option<Message>,
 
@@ -21,14 +21,13 @@ pub struct InfoDetail {
     pub subtype: Option<WarningSubtypeCode>,
 
     #[serde(rename = "updateTime")]
-    #[serde(deserialize_with = "crate::internal::deserialize::deserialize_to_option_datetime")]
     pub update_time: Option<DateTime<FixedOffset>>,
 }
 
 /// A list of `InfoDetail` that describes every warning now in force.
-#[derive(Debug, Deserialize)]
+#[derive(Clone, Debug, Deserialize)]
 pub struct Info {
     pub details: Option<Vec<InfoDetail>>,
 }
 
-impl_api!(Info, warningInfo);
+impl_api!(Info, weather, warningInfo);
